==> mahara-15.04.0_1.txz: usr/local/www/mahara/lang/en.utf8/statistics.php <==
<?php
/**
 *
 * @package    mahara
 * @subpackage lang
 * @author     Hugh Davenport <hugh@catalyst.net.nz>, Catalyst IT Ltd
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL version 3 or later
 * @copyright  For copyright information on Mahara, please see the README file distributed with this software.
 *
 */

defined('INTERNAL') || die();

// Strings for statistics
$string['allowpublicprofiles'] = 'Allow public profiles';
$string['allowpublicviews'] = 'Allow public pages';
$string['artefact_type_academicgoal'] = 'Artefact: Academic goals';
$string['artefact_type_academicskill'] = 'Artefact: Academic skills';
$string['artefact_type_address'] = 'Artefact: Postal address';
$string['artefact_type_annotation'] = 'Artefact: Annotation';
$string['artefact_type_annotationfeedback'] = 'Artefact: Annotation feedback';
$string['artefact_type_archive'] = 'Artefact: Compressed file';
$string['artefact_type_audio'] = 'Artefact: Audio file';
$string['artefact_type_blog'] = 'Artefact: Journal';
$string['artefact_type_blogaddress'] = 'Artefact: Blog address';
$string['artefact_type_blogpost'] = 'Artefact: Journal entry';
$string['artefact_type_book'] = 'Artefact: Books and publications';
$string['artefact_type_businessnumber'] = 'Artefact: Business phone';
$string['artefact_type_careergoal'] = 'Artefact: Career goals';
$string['artefact_type_certification'] = 'Artefact: Certifications, accreditations and awards';
$string['artefact_type_city'] = 'Artefact: City/region';
$string['artefact_type_comment'] = 'Artefact: Comment';
$string['artefact_type_contactinformation'] = 'Artefact: Contact information';
$string['artefact_type_country'] = 'Artefact: Country';
$string['artefact_type_coverletter'] = 'Artefact: Cover letter';
$string['artefact_type_educationhistory'] = 'Artefact: Education history';
$string['artefact_type_email'] = 'Artefact: Email';
$string['artefact_type_employmenthistory'] = 'Artefact: Employment history';
$string['artefact_type_faxnumber'] = 'Artefact: Fax number';
$string['artefact_type_file'] = 'Artefact: File';
$string['artefact_type_firstname'] = 'Artefact: First name';
$string['artefact_type_folder'] = 'Artefact: Folder';
$string['artefact_type_homenumber'] = 'Artefact: Home phone';
$string['artefact_type_html'] = 'Artefact: HTML file';
$string['artefact_type_image'] = 'Artefact: Image file';
$string['artefact_type_industry'] = 'Artefact: Industry';
$string['artefact_type_interest'] = 'Artefact: Interests';
$string['artefact_type_introduction'] = 'Artefact: Introduction';
$string['artefact_type_lastname'] = 'Artefact: Last name';
$string['artefact_type_membership'] = 'Artefact: Professional memberships';
$string['artefact_type_mobilenumber'] = 'Artefact: Mobile phone';
$string['artefact_type_occupation'] = 'Artefact: Occupation';
$string['artefact_type_officialwebsite'] = 'Artefact: Official website address';
$string['artefact_type_personalgoal'] = 'Artefact: Personal goals';
$string['artefact_type_personalinformation'] = 'Artefact: Personal information';
$string['artefact_type_personalskill'] = 'Artefact: Personal skills';
$string['artefact_type_personalwebsite'] = 'Artefact: Personal website address';
$string['artefact_type_plan'] = 'Artefact: Plans';
$string['artefact_type_preferredname'] = 'Artefact: Display name';
$string['artefact_type_profileicon'] = 'Artefact: Profile pictures';
$string['artefact_type_socialprofile'] = 'Artefact: Social media';
$string['artefact_type_studentid'] = 'Artefact: Student ID';
$string['artefact_type_task'] = 'Artefact: Task';
$string['artefact_type_town'] = 'Artefact: Town';
$string['artefact_type_video'] = 'Artefact: Video file';
$string['artefact_type_workskill'] = 'Artefact: Work skills';
$string['blocktype_annotation'] = 'Block: Annotation';
$string['blocktype_blog'] = 'Block: Journal';
$string['blocktype_blogpost'] = 'Block: Journal entry';
$string['blocktype_comment'] = 'Block: Feedback';
$string['blocktype_contactinfo'] = 'Block: Contact information';
$string['blocktype_creativecommons'] = 'Block: Creative Commons';
$string['blocktype_entireresume'] = 'Block: Entire résumé';
$string['blocktype_externalfeed'] = 'Block: External feed';
$string['blocktype_externalvideo'] = 'Block: External media';
$string['blocktype_filedownload'] = 'Block: File(s) to download';
$string['blocktype_folder'] = 'Block: Folder';
$string['blocktype_gallery'] = 'Block: Image gallery';
$string['blocktype_googleapps'] = 'Block: Google Apps';
$string['blocktype_groupinfo'] = 'Block: Group info';
$string['blocktype_groupmembers'] = 'Block: Group members';
$string['blocktype_groupviews'] = 'Block: Group pages';
$string['blocktype_html'] = 'Block: Some HTML';
$string['blocktype_pdf'] = 'Block: PDF';
$string['blocktype_image'] = 'Block: Image';
$string['blocktype_inbox'] = 'Block: My inbox';
$string['blocktype_internalmedia'] = 'Block: Embedded media';
$string['blocktype_myfriends'] = 'Block: My friends';
$string['blocktype_mygroups'] = 'Block: My groups';
$string['blocktype_myviews'] = 'Block: My pages';
$string['blocktype_navigation'] = 'Block: Navigation';
$string['blocktype_newviews'] = 'Block: Latest pages';
$string['blocktype_plans'] = 'Block: Plans';
$string['blocktype_profileinfo'] = 'Block: Profile information';
$string['blocktype_recentforumposts'] = 'Block: Recent forum posts';
$string['blocktype_recentposts'] = 'Block: Recent journal entries';
$string['blocktype_resumefield'] = 'Block: Résumé field';
$string['blocktype_taggedposts'] = 'Block: Tagged journal entries';
$string['blocktype_text'] = 'Block: Text';
$string['blocktype_textbox'] = 'Block: Note';
$string['blocktype_socialprofile'] = 'Block: Social media';
$string['blocktype_wall'] = 'Block: Wall';
$string['blocktype_watchlist'] = 'Block: Watched pages';
$string['count_block_instance'] = 'Number of blocks';
$string['count_blocktype_wall_post'] = 'Number of wall posts';
$string['count_group'] = 'Number of groups';
$string['count_group_member'] = 'Number of group members';
$string['count_host'] = 'Number of Moodle hosts';
$string['count_institution'] = 'Number of institutions';
$string['count_interaction_forum_post'] = 'Number of forum posts';
$string['count_usr'] = 'Number of users';
$string['count_usr_friend'] = 'Number of friend relationships';
$string['count_usr_institution'] = 'Number of users in institutions';
$string['count_members'] = 'Number of members of institution';
$string['count_artefacts'] = 'Number of artefacts';
$string['count_blocks'] = 'Number of blocks';
$string['count_views'] = 'Number of pages';
$string['dbtype'] = 'Database type';
$string['enablenetworking'] = 'Enabled networking';
$string['installation_key'] = 'Installation key';
$string['lang'] = 'Language';
$string['newstats'] = 'New statistics';
$string['plugin_artefact_blog_version'] = 'Artefact plugin Journal version';
$string['plugin_artefact_comment_version'] = 'Artefact plugin Comment version';
$string['plugin_artefact_file_version'] = 'Artefact plugin File version';
$string['plugin_artefact_internal_version'] = 'Artefact plugin XXXXXX version';
$string['plugin_artefact_plans_version'] = 'Artefact plugin Plans version';
$string['plugin_artefact_resume_version'] = 'Artefact plugin Résumé version';
$string['plugin_auth_browserid_version'] = 'Authentication plugin Persona version';
$string['plugin_auth_imap_version'] = 'Authentication plugin IMAP version';
$string['plugin_auth_internal_version'] = 'Authentication plugin Internal version';
$string['plugin_auth_ldap_version'] = 'Authentication plugin LDAP version';
$string['plugin_auth_none_version'] = 'Authentication plugin None version';
$string['plugin_auth_saml_version'] = 'Authentication plugin SAML version';
$string['plugin_auth_xmlrpc_version'] = 'Authentication plugin XML-RPC version';
$string['plugin_blocktype_blogpost_version'] = 'Block type plugin Journal entry version';
$string['plugin_blocktype_blog_version'] = 'Block type plugin Journal version';
$string['plugin_blocktype_contactinfo_version'] = 'Block type plugin Contact information version';
$string['plugin_blocktype_creativecommons_version'] = 'Block type plugin Creative Commons version';
$string['plugin_blocktype_entireresume_version'] = 'Block type plugin Entire résumé version';
$string['plugin_blocktype_externalfeed_version'] = 'Block type plugin External feed version';
$string['plugin_blocktype_externalvideo_version'] = 'Block type plugin External media version';
$string['plugin_blocktype_filedownload_version'] = 'Block type plugin File(s) to download version';
$string['plugin_blocktype_folder_version'] = 'Block type plugin Folder version';
$string['plugin_blocktype_gallery_version'] = 'Block type plugin Image gallery version';
$string['plugin_blocktype_googleapps_version'] = 'Block type plugin Google Apps version';
$string['plugin_blocktype_groupinfo_version'] = 'Block type plugin Group info version';
$string['plugin_blocktype_groupmembers_version'] = 'Block type plugin Group members version';
$string['plugin_blocktype_groupviews_version'] = 'Block type plugin Group pages version';
$string['plugin_blocktype_html_version'] = 'Block type plugin Some HTML version';
$string['plugin_blocktype_html_version'] = 'Block type plugin PDF version';
$string['plugin_blocktype_image_version'] = 'Block type plugin Image version';
$string['plugin_blocktype_inbox_version'] = 'Block type plugin Inbox version';
$string['plugin_blocktype_internalmedia_version'] = 'Block type plugin Embedded media version';
$string['plugin_blocktype_myfriends_version'] = 'Block type plugin My friends version';
$string['plugin_blocktype_mygroups_version'] = 'Block type plugin My groups version';
$string['plugin_blocktype_myviews_version'] = 'Block type plugin My pages version';
$string['plugin_blocktype_navigation_version'] = 'Block type plugin Navigation version';
$string['plugin_blocktype_newviews_version'] = 'Block type plugin Latest pages version';
$string['plugin_blocktype_plans_version'] = 'Block type plugin Plans version';
$string['plugin_blocktype_profileinfo_version'] = 'Block type plugin Profile information version';
$string['plugin_blocktype_recentforumposts_version'] = 'Block type plugin Recent forum posts version';
$string['plugin_blocktype_recentposts_version'] = 'Block type plugin Recent journal posts version';
$string['plugin_blocktype_resumefield_version'] = 'Block type plugin Single résumé field version';
$string['plugin_blocktype_taggedposts_version'] = 'Block type plugin Tagged journal entries version';
$string['plugin_blocktype_textbox_version'] = 'Block type plugin Note version';
$string['plugin_blocktype_wall_version'] = 'Block type plugin Wall version';
$string['plugin_blocktype_watchlist_version'] = 'Block type plugin Watched pages version';
$string['plugin_export_html_version'] = 'Export plugin HTML version';
$string['plugin_export_leap_version'] = 'Export plugin Leap2A version';
$string['plugin_grouptype_course_version'] = 'Group type plugin Course version';
$string['plugin_grouptype_standard_version'] = 'Group type plugin Standard version';
$string['plugin_import_file_version'] = 'Import plugin File version';
$string['plugin_import_leap_version'] = 'Import plugin Leap2A version';
$string['plugin_interaction_forum_version'] = 'Interaction plugin Forum version';
$string['plugin_notification_emaildigest_version'] = 'Notification plugin Email digest version';
$string['plugin_notification_email_version'] = 'Notification plugin Email version';
$string['plugin_notification_internal_version'] = 'Notification plugin Internal version';
$string['plugin_search_internal_version'] = 'Search plugin Internal version';
$string['release'] = 'Release';
$string['sitename'] = 'Site name';
$string['theme'] = 'Theme';
$string['usersloggedin'] = 'Number of logged-in users in the last week';
$string['version'] = 'Version';
$string['view_type_dashboard'] = 'Number of dashboards';
$string['view_type_grouphomepage'] = 'Number of group homepages';
$string['view_type_portfolio'] = 'Number of portfolio pages';
$string['view_type_profile'] = 'Number of profile pages';
$string['wwwroot'] = 'WWW root';

==> mahara-16.04.3.txz: usr/local/www/mahara/lang/en.utf8/statistics.php <==
<?php
/**
 *
 * @package    mahara
 * @subpackage lang
 * @author     Hugh Davenport <hugh@catalyst.net.nz>, Catalyst IT Ltd
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL version 3 or later
 * @copyright  For copyright information on Mahara, please see the README file distributed with this software.
 *
 */

defined('INTERNAL') || die();

// Strings for statistics
$string['allowpublicprofiles'] = 'Allow public profiles';
$string['allowpublicviews'] = 'Allow public pages';
$string['artefact_type_academicgoal'] = 'Artefact: Academic goals';
$string['artefact_type_academicskill'] = 'Artefact: Academic skills';
$string['artefact_type_address'] = 'Artefact: Postal address';
$string['artefact_type_annotation'] = 'Artefact: Annotation';
$string['artefact_type_annotationfeedback'] = 'Artefact: Annotation feedback';
$string['artefact_type_archive'] = 'Artefact: Compressed file';
$string['artefact_type_audio'] = 'Artefact: Audio file';
$string['artefact_type_blog'] = 'Artefact: Journal';
$string['artefact_type_blogaddress'] = 'Artefact: Blog address';
$string['artefact_type_blogpost'] = 'Artefact: Journal entry';
$string['artefact_type_book'] = 'Artefact: Books and publications';
$string['artefact_type_businessnumber'] = 'Artefact: Business phone';
$string['artefact_type_careergoal'] = 'Artefact: Career goals';
$string['artefact_type_certification'] = 'Artefact: Certifications, accreditations and awards';
$string['artefact_type_city'] = 'Artefact: City/region';
$string['artefact_type_comment'] = 'Artefact: Comment';
$string['artefact_type_contactinformation'] = 'Artefact: Contact information';
$string['artefact_type_country'] = 'Artefact: Country';
$string['artefact_type_coverletter'] = 'Artefact: Cover letter';
$string['artefact_type_educationhistory'] = 'Artefact: Education history';
$string['artefact_type_email'] = 'Artefact: Email';
$string['artefact_type_employmenthistory'] = 'Artefact: Employment history';
$string['artefact_type_faxnumber'] = 'Artefact: Fax number';
$string['artefact_type_file'] = 'Artefact: File';
$string['artefact_type_firstname'] = 'Artefact: First name';
$string['artefact_type_folder'] = 'Artefact: Folder';
$string['artefact_type_homenumber'] = 'Artefact: Home phone';
$string['artefact_type_html'] = 'Artefact: HTML file';
$string['artefact_type_image'] = 'Artefact: Image file';
$string['artefact_type_industry'] = 'Artefact: Industry';
$string['artefact_type_interest'] = 'Artefact: Interests';
$string['artefact_type_introduction'] = 'Artefact: Introduction';
$string['artefact_type_lastname'] = 'Artefact: Last name';
$string['artefact_type_membership'] = 'Artefact: Professional memberships';
$string['artefact_type_mobilenumber'] = 'Artefact: Mobile phone';
$string['artefact_type_occupation'] = 'Artefact: Occupation';
$string['artefact_type_officialwebsite'] = 'Artefact: Official website address';
$string['artefact_type_personalgoal'] = 'Artefact: Personal goals';
$string['artefact_type_personalinformation'] = 'Artefact: Personal information';
$string['artefact_type_personalskill'] = 'Artefact: Personal skills';
$string['artefact_type_personalwebsite'] = 'Artefact: Personal website address';
$string['artefact_type_plan'] = 'Artefact: Plans';
$string['artefact_type_preferredname'] = 'Artefact: Display name';
$string['artefact_type_profileicon'] = 'Artefact: Profile pictures';
$string['artefact_type_socialprofile'] = 'Artefact: Social media';
$string['artefact_type_studentid'] = 'Artefact: Student ID';
$string['artefact_type_task'] = 'Artefact: Task';
$string['artefact_type_town'] = 'Artefact: Town';
$string['artefact_type_video'] = 'Artefact: Video file';
$string['artefact_type_workskill'] = 'Artefact: Work skills';
$string['blocktype_annotation'] = 'Block: Annotation';
$string['blocktype_blog'] = 'Block: Journal';
$string['blocktype_blogpost'] = 'Block: Journal entry';
$string['blocktype_comment'] = 'Block: Feedback';
$string['blocktype_contactinfo'] = 'Block: Contact information';
$string['blocktype_creativecommons'] = 'Block: Creative Commons';
$string['blocktype_entireresume'] = 'Block: Entire résumé';
$string['blocktype_externalfeed'] = 'Block: External feed';
$string['blocktype_externalvideo'] = 'Block: External media';
$string['blocktype_filedownload'] = 'Block: File(s) to download';
$string['blocktype_folder'] = 'Block: Folder';
$string['blocktype_gallery'] = 'Block: Image gallery';
$string['blocktype_googleapps'] = 'Block: Google Apps';
$string['blocktype_groupinfo'] = 'Block: Group info';
$string['blocktype_groupmembers'] = 'Block: Group members';
$string['blocktype_groupviews'] = 'Block: Group pages';
$string['blocktype_html'] = 'Block: Some HTML';
$string['blocktype_pdf'] = 'Block: PDF';
$string['blocktype_image'] = 'Block: Image';
$string['blocktype_inbox'] = 'Block: My inbox';
$string['blocktype_internalmedia'] = 'Block: Embedded media';
$string['blocktype_myfriends'] = 'Block: My friends';
$string['blocktype_mygroups'] = 'Block: My groups';
$string['blocktype_myviews'] = 'Block: My portfolios';
$string['blocktype_navigation'] = 'Block: Navigation';
$string['blocktype_newviews'] = 'Block: Latest pages';
$string['blocktype_plans'] = 'Block: Plans';
$string['blocktype_profileinfo'] = 'Block: Profile information';
$string['blocktype_recentforumposts'] = 'Block: Recent forum posts';
$string['blocktype_recentposts'] = 'Block: Recent journal entries';
$string['blocktype_resumefield'] = 'Block: Résumé field';
$string['blocktype_taggedposts'] = 'Block: Tagged journal entries';
$string['blocktype_text'] = 'Block: Text';
$string['blocktype_textbox'] = 'Block: Note';
$string['blocktype_socialprofile'] = 'Block: Social media';
$string['blocktype_wall'] = 'Block: Wall';
$string['blocktype_watchlist'] = 'Block: Watched pages';
$string['count_block_instance'] = 'Number of blocks';
$string['count_blocktype_wall_post'] = 'Number of wall posts';
$string['count_group'] = 'Number of groups';
$string['count_group_member'] = 'Number of group members';
$string['count_host'] = 'Number of Moodle hosts';
$string['count_institution'] = 'Number of institutions';
$string['count_interaction_forum_post'] = 'Number of forum posts';
$string['count_usr'] = 'Number of users';
$string['count_usr_friend'] = 'Number of friend relationships';
$string['count_usr_institution'] = 'Number of users in institutions';
$string['count_members'] = 'Number of members of institution';
$string['count_artefacts'] = 'Number of artefacts';
$string['count_blocks'] = 'Number of blocks';
$string['count_views'] = 'Number of pages';
$string['dbtype'] = 'Database type';
$string['enablenetworking'] = 'Enabled networking';
$string['grouptypes'] = 'Group types';
$string['installation_key'] = 'Installation key';
$string['lang'] = 'Language';
$string['newstats'] = 'New statistics';
$string['plugin_artefact_blog_version'] = 'Artefact plugin Journal version';
$string['plugin_artefact_comment_version'] = 'Artefact plugin Comment version';
$string['plugin_artefact_file_version'] = 'Artefact plugin File version';
$string['plugin_artefact_internal_version'] = 'Artefact plugin XXXXXX version';
$string['plugin_artefact_plans_version'] = 'Artefact plugin Plans version';
$string['plugin_artefact_resume_version'] = 'Artefact plugin Résumé version';
$string['plugin_auth_browserid_version'] = 'Authentication plugin Persona version';
$string['plugin_auth_imap_version'] = 'Authentication plugin IMAP version';
$string['plugin_auth_internal_version'] = 'Authentication plugin Internal version';
$string['plugin_auth_ldap_version'] = 'Authentication plugin LDAP version';
$string['plugin_auth_none_version'] = 'Authentication plugin None version';
$string['plugin_auth_saml_version'] = 'Authentication plugin SAML version';
$string['plugin_auth_xmlrpc_version'] = 'Authentication plugin XML-RPC version';
$string['plugin_blocktype_blogpost_version'] = 'Block type plugin Journal entry version';
$string['plugin_blocktype_blog_version'] = 'Block type plugin Journal version';
$string['plugin_blocktype_contactinfo_version'] = 'Block type plugin Contact information version';
$string['plugin_blocktype_creativecommons_version'] = 'Block type plugin Creative Commons version';
$string['plugin_blocktype_entireresume_version'] = 'Block type plugin Entire résumé version';
$string['plugin_blocktype_externalfeed_version'] = 'Block type plugin External feed version';
$string['plugin_blocktype_externalvideo_version'] = 'Block type plugin External media version';
$string['plugin_blocktype_filedownload_version'] = 'Block type plugin File(s) to download version';
$string['plugin_blocktype_folder_version'] = 'Block type plugin Folder version';
$string['plugin_blocktype_gallery_version'] = 'Block type plugin Image gallery version';
$string['plugin_blocktype_googleapps_version'] = 'Block type plugin Google Apps version';
$string['plugin_blocktype_groupinfo_version'] = 'Block type plugin Group info version';
$string['plugin_blocktype_groupmembers_version'] = 'Block type plugin Group members version';
$string['plugin_blocktype_groupviews_version'] = 'Block type plugin Group pages version';
$string['plugin_blocktype_html_version'] = 'Block type plugin Some HTML version';
$string['plugin_blocktype_html_version'] = 'Block type plugin PDF version';
$string['plugin_blocktype_image_version'] = 'Block type plugin Image version';
$string['plugin_blocktype_inbox_version'] = 'Block type plugin Inbox version';
$string['plugin_blocktype_internalmedia_version'] = 'Block type plugin Embedded media version';
$string['plugin_blocktype_myfriends_version'] = 'Block type plugin My friends version';
$string['plugin_blocktype_mygroups_version'] = 'Block type plugin My groups version';
$string['plugin_blocktype_myviews_version'] = 'Block type plugin My portfolios version';
$string['plugin_blocktype_navigation_version'] = 'Block type plugin Navigation version';
$string['plugin_blocktype_newviews_version'] = 'Block type plugin Latest pages version';
$string['plugin_blocktype_plans_version'] = 'Block type plugin Plans version';
$string['plugin_blocktype_profileinfo_version'] = 'Block type plugin Profile information version';
$string['plugin_blocktype_recentforumposts_version'] = 'Block type plugin Recent forum posts version';
$string['plugin_blocktype_recentposts_version'] = 'Block type plugin Recent journal posts version';
$string['plugin_blocktype_resumefield_version'] = 'Block type plugin Single résumé field version';
$string['plugin_blocktype_taggedposts_version'] = 'Block type plugin Tagged journal entries version';
$string['plugin_blocktype_textbox_version'] = 'Block type plugin Note version';
$string['plugin_blocktype_wall_version'] = 'Block type plugin Wall version';
$string['plugin_blocktype_watchlist_version'] = 'Block type plugin Watched pages version';
$string['plugin_export_html_version'] = 'Export plugin HTML version';
$string['plugin_export_leap_version'] = 'Export plugin Leap2A version';
$string['plugin_grouptype_course_version'] = 'Group type plugin Course version';
$string['plugin_grouptype_standard_version'] = 'Group type plugin Standard version';
$string['plugin_import_file_version'] = 'Import plugin File version';
$string['plugin_import_leap_version'] = 'Import plugin Leap2A version';
$string['plugin_interaction_forum_version'] = 'Interaction plugin Forum version';
$string['plugin_notification_emaildigest_version'] = 'Notification plugin Email digest version';
$string['plugin_notification_email_version'] = 'Notification plugin Email version';
$string['plugin_notification_internal_version'] = 'Notification plugin Internal version';
$string['plugin_search_internal_version'] = 'Search plugin Internal version';
$string['release'] = 'Release';
$string['sitename'] = 'Site name';
$string['theme'] = 'Theme';
$string['usersloggedin'] = 'Number of logged-in users in the last week';
$string['version'] = 'Version';
$string['view_type_dashboard'] = 'Number of dashboards';
$string['view_type_grouphomepage'] = 'Number of group homepages';
$string['view_type_portfolio'] = 'Number of portfolio pages';
$string['view_type_profile'] = 'Number of profile pages';
$string['wwwroot'] = 'WWW root';
$string['sitedataweekly'] = 'Weekly site data';

$string['group-count'] = 'Groups';
$string['view-count'] = 'Views';
$string['user-count'] = 'User';
$string['institutiondataweekly'] = 'Institution weekly data';
$string['usersbytype'] = 'Users by type';
$string['staff'] = 'Staff';
$string['admins'] = 'Administrators';

$string['activeusers'] = "Active users";
$string['logins'] = "Logins";
